/***************************************************************************
 * Copyright 2012 by
 *  + Christian-Albrechts-University of Kiel
 *    + Department of Computer Science
 *      + Software Engineering Group 
 *  and others.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 ***************************************************************************/

package kieker.webgui.beans.session;

import javax.faces.bean.ManagedBean;
import javax.faces.bean.SessionScoped;
import javax.faces.context.FacesContext;

import kieker.webgui.beans.application.DependenciesBean;

import org.primefaces.model.UploadedFile;

/**
 * 
 * @author Nils Christian Ehmke
 * @version 1.0
 */
@ManagedBean
@SessionScoped
public class DependencyUploadBean {

	/**
	 * The file stored within this bean.
	 */
	private UploadedFile file;

	/**
	 * Creates a new instance of this class.
	 */
	public DependencyUploadBean() {
		/* No code necessary. */
	}

	/**
	 * Delivers the instance stored within this bean.
	 * 
	 * @return The currently stored value within this bean.
	 */
	public UploadedFile getFile() {
		return this.file;
	}

	/**
	 * Sets the new value of the bean.
	 * 
	 * @param file
	 *            The file instance to be stored within this bean.
	 */
	public void setFile(final UploadedFile file) {
		this.file = file;
	}

	/**
	 * Tries to upload the currently stored value within this bean.
	 */
	public void upload() {
		if (this.file != null) {
			final FacesContext context = FacesContext.getCurrentInstance();
			final DependenciesBean bean = context.getApplication().evaluateExpressionGet(context, "#{availableDependenciesBean}",
					DependenciesBean.class);
			if (bean != null) {
				bean.uploadDependency(this.file);
			}
		}
	}
}
